@@ -18,7 +18,7 @@
    Software Foundation, 59 Temple Place - Suite 330, Boston, MA
    02111-1307, USA.  */
 
-/*	$Id: glue.c,v 1.17 2004/11/15 00:47:12 rrt Exp $	*/
+/*	$Id: glue.c,v 1.17.2.1 2005/05/27 15:41:50 rrt Exp $	*/
 
 #include "config.h"
 
@@ -237,23 +237,3 @@ void ztrace(const char *fmt, ...)
 	va_end(ap);
 }
 #endif
-
-/*
- * Read an arbitrary length string.
- */
-char *
-getln(FILE *fp)
-{
-        size_t len = 256;
-        int c;
-        char *l = zmalloc(len), *s = l;
-
-        for (c = getc(fp); c != '\n' && c != EOF; c = getc(fp)) {
-                if (s == l + len)
-                        zrealloc(l, len *= 2);
-                *s++ = c;
-        }
-        *s = '\0';
-
-        return l;
-}
