@@ -18,7 +18,7 @@
    Software Foundation, 59 Temple Place - Suite 330, Boston, MA
    02111-1307, USA.  */
 
-/*	$Id: main.c,v 1.50.2.11 2005/02/27 17:43:50 rrt Exp $	*/
+/*	$Id: main.c,v 1.50.2.12 2005/05/19 23:29:11 rrt Exp $	*/
 
 #include "config.h"
 
@@ -310,16 +310,19 @@ static struct sigaction act; /* For use by signal handlers */
 /* What do we do when we catch the suspend signal */
 static void suspend_sig_handler(int signal)
 {
-	/* Clear last line of display, and leave cursor there. */
-	term_move(ZILE_LINES - 1, 0);
-	term_clrtoeol();
-        term_attrset(1, ZILE_NORMAL); /* Make sure we end in normal font */
-	term_refresh();
-        term_suspend();
+        if (termp->initted) {
+                /* Clear last line of display, and leave cursor there. */
+                term_move(ZILE_LINES - 1, 0);
+                term_clrtoeol();
+                term_attrset(1, ZILE_NORMAL); /* Make sure we end in normal font */
+                term_refresh();
+                term_suspend();
+        }
 
         /* Trap SIGHUP and SIGTERM so we can properly deal with them while
            suspended */
         act.sa_handler = other_sig_handler;
+        act.sa_flags = SA_RESTART;
         sigaction(SIGHUP, &act, NULL);
         sigaction(SIGTERM, &act, NULL);
 
@@ -334,8 +337,10 @@ static void signal_init(void);
 /* Restore the suspend handler when we come back into the prog */
 static void cont_sig_handler(int signal)
 {
-        term_resume();
-        term_full_redisplay(); /* XXX need to call tcsetattr and winch handler */
+        if (termp->initted) {
+                term_resume();
+                term_full_redisplay(); /* XXX need to call tcsetattr and winch handler */
+        }
 
         /* Simplest just to reinitialise everything. */
         signal_init();
@@ -357,6 +362,7 @@ static void signal_init(void)
 	   pine or mutt freezes the process. */
 	sigfillset(&act.sa_mask);
 
+        act.sa_flags = SA_RESTART;
 	act.sa_handler = suspend_sig_handler;
 	sigaction(SIGTSTP, &act, NULL);
 	act.sa_handler = cont_sig_handler;
