@@ -20,7 +20,7 @@
    Software Foundation, 59 Temple Place - Suite 330, Boston, MA
    02111-1307, USA.  */
 
-/*	$Id: term_termcap.c,v 1.42.2.11 2005/04/05 16:58:57 rrt Exp $	*/
+/*	$Id: term_termcap.c,v 1.42.2.14 2005/05/20 14:28:37 rrt Exp $	*/
 
 #include "config.h"
 
@@ -43,6 +43,9 @@ static Terminal thisterm = {
 
 	/* Uninitialized width and height. */
 	-1, -1,
+
+        /* Uninitialised */
+        FALSE,
 };
 
 typedef struct {
@@ -104,7 +107,8 @@ void term_clrtoeol(void)
         screen.curx = x;
 }
 
-static const char *getattr(Font f) {
+static const char *getattr(Font f)
+{
         if (f == ZILE_NORMAL)
                 return astr_cstr(norm_string);
         else if (f & ZILE_BOLD)
@@ -115,6 +119,16 @@ static const char *getattr(Font f) {
         return "";
 }
 
+static char *zgoto(const char *s, int col, int row)
+{
+        char *ret = tgoto(s, col, row);
+        if (ret == NULL) {
+                fprintf(stderr, "zile: can't position cursor\n");
+                zile_exit(1);
+        }
+        return ret;
+}
+
 /*
  * Refresh the screen.  This is basically a poor person's ncurses.
  * To minimise the number of system calls, the output is collected in a string.
@@ -132,7 +146,7 @@ void term_refresh(void)
         astr as = astr_new();
 
         /* Start at the top left of the screen with no highlighting. */
-        astr_cat_cstr(as, tgoto(cm_string, 0, 0));
+        astr_cat_cstr(as, zgoto(cm_string, 0, 0));
         astr_cat_cstr(as, getattr(ZILE_NORMAL));
 
         /* Add the rest of the screen. */
@@ -144,7 +158,7 @@ void term_refresh(void)
                  * rest of the line to be updated in the array (it should be
                  * all zeros).
                  */
-                astr_cat_cstr(as, tgoto(cm_string, 0, i));
+                astr_cat_cstr(as, zgoto(cm_string, 0, i));
 		skipped = FALSE;
 
                 for (j = 0; j < termp->width; j++) {
@@ -155,7 +169,7 @@ void term_refresh(void)
 
                         if (screen.oarray[offset] != n) {
                                 if (skipped)
-                                        astr_cat_cstr(as, tgoto(cm_string, j, i));
+                                        astr_cat_cstr(as, zgoto(cm_string, j, i));
 				skipped = FALSE;
 
                                 screen.oarray[offset] = n;
@@ -179,7 +193,7 @@ void term_refresh(void)
         }
 
         /* Put the cursor back where it should be. */
-        astr_cat_cstr(as, tgoto(cm_string, screen.curx, screen.cury));
+        astr_cat_cstr(as, zgoto(cm_string, screen.curx, screen.cury));
 
         /* Display the output. */
         write(STDOUT_FILENO, astr_cstr(as), astr_len(as));
@@ -317,7 +331,7 @@ static char *tgetstr_note_len(const char *cap, char **tcap)
 static void setattr(int flags, struct termios *state)
 {
         if (tcsetattr(0, flags, state) < 0) {
-                fprintf(stderr, "Can't set terminal mode\n");
+                perror("zile: can't set terminal mode");
                 zile_exit(1);
         }
 }
@@ -339,7 +353,7 @@ void term_init(void)
 
         /* Save terminal flags. */
         if ((tcgetattr(0, &ostate) < 0) || (tcgetattr(0, &nstate) < 0)) {
-                fprintf(stderr, "Can't read terminal capabilites\n");
+                perror("zile: can't read terminal capabilites");
                 zile_exit(1);
         }
 
@@ -379,6 +393,8 @@ void term_init(void)
         astr_cat_cstr(norm_string, me_string);
 
         printf("%s", ks_string); /* Activate keypad (including cursor keys). */
+
+        termp->initted = TRUE;
 }
 
 void term_close(void)
@@ -395,7 +411,7 @@ void term_close(void)
         tcdrain(0);
         fflush(stdout);
         if (tcsetattr(0, TCSADRAIN, &ostate) < 0) {
-                fprintf(stderr, "Can't restore terminal flags\n");
+                perror("zile: can't restore terminal flags");
                 zile_exit(1);
         }
 }
@@ -497,7 +513,7 @@ static size_t getchars(char *keys, size_t nbytes)
         int nread = 1;
 
         while (nread >= 0 && nbytes < max_key_chars && nread) {
-                nread = read(STDIN_FILENO, keys + nbytes, max_key_chars);
+                nread = read(STDIN_FILENO, keys + nbytes, max_key_chars - nbytes);
                 if (nread >= 0)
                         nbytes += nread;
 
