@@ -20,7 +20,7 @@
    Software Foundation, 59 Temple Place - Suite 330, Boston, MA
    02111-1307, USA.  */
 
-/*      $Id: zile.h,v 1.37 2004/12/27 01:10:07 rrt Exp $        */
+/*      $Id: zile.h,v 1.37.2.1 2005/05/19 23:29:11 rrt Exp $        */
 
 #ifndef ZILE_H
 #define ZILE_H
@@ -249,6 +249,8 @@ struct Terminal {
         void *screen; /* The real type of this pointer depends on the
                          terminal back-end. */
         int width, height;
+        int initted; /* Set to TRUE when the terminal has been
+                        initialised. */
 };
 
 /* The actual number of lines and columns on the screen, which may
